@@ -36,10 +36,10 @@
 
 
 /////////////////////// Qt includes
-#include <QtGui>
-#include <QtXml>
-#include <QtGlobal>
-
+#include<QtGui>
+#include<QtXml>
+#include<QtGlobal>
+#include<QMessageBox>
 
 /////////////////////// Local includes
 #include "calculatorWnd.hpp"
@@ -1315,7 +1315,8 @@ namespace massXpert
   
     // It cannot be that the text in the combobox does not correspond to
     // a known monomer.
-    Q_ASSERT(index != -1);
+    if (index == -1)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
   
     // Prepare the recorder string.
   
@@ -1361,7 +1362,8 @@ namespace massXpert
   
     // It cannot be that the text in the combobox does not correspond to
     // a known modif.
-    Q_ASSERT(index != -1);
+    if (index == -1)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
   
     // Prepare the recorder string.
   
