@@ -869,10 +869,10 @@ namespace massXpert
 	m_ui.cleaveRuleNameLineEdit->setText(cleaveRule->name());
       
 	m_ui.leftCodeLineEdit->setText(cleaveRule->leftCode());
-	m_ui.leftFormulaLineEdit->setText(cleaveRule->leftFormula().formula());
+	m_ui.leftFormulaLineEdit->setText(cleaveRule->leftFormula().text());
 
 	m_ui.rightCodeLineEdit->setText(cleaveRule->rightCode());
-	m_ui.rightFormulaLineEdit->setText(cleaveRule->rightFormula().formula());
+	m_ui.rightFormulaLineEdit->setText(cleaveRule->rightFormula().text());
       }
     else
       {
