@@ -162,7 +162,12 @@ namespace massXpert
 	     SIGNAL(clicked()),
 	     this, 
 	     SLOT(applyMonomerPushButtonClicked()));
-  
+
+    connect(m_ui.formulaLineEdit,
+	    SIGNAL(textChanged(const QString &)),
+	    this,
+	    SLOT(formulaLineEditTextChanged(const QString &)));
+      
     connect(m_ui.validatePushButton, 
 	     SIGNAL(clicked()),
 	     this, 
@@ -177,8 +182,12 @@ namespace massXpert
 	     SIGNAL(valueChanged(int)),
 	     this,
 	     SLOT(codeLengthSpinBoxValueChanged(int)));
-  
 
+    connect(m_ui.calculateMassDifferencesPushButton, 
+	    SIGNAL(clicked()),
+	    this, 
+	    SLOT(calculateMassDifferences()));
+    
     return true;
   }
 
@@ -554,4 +563,82 @@ namespace massXpert
     return validatePushButtonClicked();
   }
 
+  void
+  MonomerDefDlg::formulaLineEditTextChanged(const QString &string)
+  {
+    // Each time the formula of the monomer is edited, we compute the
+    // masses of the formula. If the computation failed, we set "Bad
+    // formula" in the line edit widgets of the masses.
+
+    const QList<Atom *> &atomList = mp_polChemDef->atomList();
+    
+    Formula formula(string);
+    
+    Ponderable ponderable (0,0);
+        
+    if (!formula.accountMasses(atomList, &ponderable))
+      {
+	m_ui.monoMassLineEdit->setText(tr("Bad formula"));
+	m_ui.avgMassLineEdit->setText(tr("Bad formula"));
+	
+	return;
+      }
+
+    Application *application = static_cast<Application *>(qApp);
+    QLocale locale = application->locale();
+
+    m_ui.monoMassLineEdit->
+      setText(ponderable.mono(locale, MXP_ATOM_DEC_PLACES));
+
+    m_ui.avgMassLineEdit->
+      setText(ponderable.avg(locale, MXP_ATOM_DEC_PLACES));
+  }
+  
+
+  void
+  MonomerDefDlg::calculateMassDifferences()
+  {
+    // Allocate a new QStringList object in which all the mass
+    // differences between any two monomers in the definitions are
+    // below the threshold set into the thresholdLineEdit.
+
+    bool ok = false;
+    
+    double threshold = m_ui.thresholdLineEdit->text().toDouble(&ok);
+    
+    if (!threshold && !ok)
+      {
+	QMessageBox::warning(this, 
+			     tr("massXpert - Monomer definition"),
+			     tr("Threshold value is not valid"),
+			     QMessageBox::Ok);
+	return;
+      }
+    
+    bool isMonoMass = m_ui.monoMassRadioButton->isChecked();
+    
+    int monoOrAvg;
+    
+    if (isMonoMass)
+      monoOrAvg = MXT_MASS_MONO;
+    else
+      monoOrAvg = MXT_MASS_AVG;
+    
+    QStringList *diffList = 
+      mp_polChemDef->differenceBetweenMonomers(threshold, monoOrAvg);
+    
+    if (!diffList)
+      return;
+    
+    QMessageBox::information(this, 
+			     tr("massXpert - Monomer definition"),
+			     diffList->join("\n"),
+			     QMessageBox::Ok);
+    
+    delete diffList;
+    
+    return;
+  }
+  
+
 } // namespace massXpert
