@@ -45,9 +45,8 @@
 #include "calcOptions.hpp"
 #include "polymer.hpp"
 #include "ionizeRule.hpp"
-#include "fragmentOligomer.hpp"
 #include "oligomerList.hpp"
-
+#include "crossLinkedRegion.hpp"
 
 namespace massXpert
 {
@@ -64,6 +63,11 @@ namespace massXpert
     // Pointer to an oligomer list which WE DO NOT OWN.
     OligomerList *mp_oligomerList;
 
+    // A list of CrossLinkedRegion instances that we compute in case
+    // there are cross-links in the fragmented sequence.
+    QList<CrossLinkedRegion *> m_crossLinkedRegionList;
+        
+
   public:
     Fragmenter(Polymer *, const PolChemDef *, 
 		const QList<FragOptions *> &fragOptionList,
